==> haskell-magic-1.1-22-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-magic.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 magic
version:              1.1
visibility:           public
id:                   magic-1.1-ACgJfsTtmRc6ULiEKeUBqR
key:                  magic-1.1-ACgJfsTtmRc6ULiEKeUBqR
license:              BSD-3-Clause
copyright:            Copyright (c) 2005-2009 John Goerzen
maintainer:           John Goerzen <jgoerzen@complete.org>
author:               John Goerzen
stability:            Alpha
synopsis:             Interface to C file/magic library
description:
    This package provides a Haskell interface to the C libmagic library.
    With it, you can determine the type of a file by examining its contents
    rather than its name.  The Haskell interface provides a full-featured
    binding.

category:             Text
abi:                  79670a3f056e65f210db15a431e38768
exposed:              True
exposed-modules:
    Magic Magic.Data Magic.Init Magic.Operations Magic.Types

hidden-modules:       Magic.Utils Magic.TypesLL
import-dirs:          /usr/lib/ghc-8.10.5/site-local/magic-1.1
library-dirs:         /usr/lib/ghc-8.10.5/site-local/magic-1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.5/magic-1.1
hs-libraries:         HSmagic-1.1-ACgJfsTtmRc6ULiEKeUBqR
extra-libraries:      magic
depends:              base-4.14.2.0
haddock-interfaces:   /usr/share/doc/haskell-magic/html/magic.haddock
haddock-html:         /usr/share/doc/haskell-magic/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-magic-1.1-23-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-magic.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 magic
version:              1.1
visibility:           public
id:                   magic-1.1-7fFfTm2bHYZ3cy9d71UYSk
key:                  magic-1.1-7fFfTm2bHYZ3cy9d71UYSk
license:              BSD-3-Clause
copyright:            Copyright (c) 2005-2009 John Goerzen
maintainer:           John Goerzen <jgoerzen@complete.org>
author:               John Goerzen
stability:            Alpha
synopsis:             Interface to C file/magic library
description:
    This package provides a Haskell interface to the C libmagic library.
    With it, you can determine the type of a file by examining its contents
    rather than its name.  The Haskell interface provides a full-featured
    binding.

category:             Text
abi:                  986a7b83f57287ff04ecbd6965e4de4d
exposed:              True
exposed-modules:
    Magic Magic.Data Magic.Init Magic.Operations Magic.Types

hidden-modules:       Magic.Utils Magic.TypesLL
import-dirs:          /usr/lib/ghc-9.0.1/site-local/magic-1.1
library-dirs:         /usr/lib/ghc-9.0.1/site-local/magic-1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/magic-1.1
hs-libraries:         HSmagic-1.1-7fFfTm2bHYZ3cy9d71UYSk
extra-libraries:      magic
depends:              base-4.15.0.0
haddock-interfaces:   /usr/share/doc/haskell-magic/html/magic.haddock
haddock-html:         /usr/share/doc/haskell-magic/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
